@@ -1,6 +1,5 @@
 import operator
 
-from Orange.canvas import report
 from os import path
 import time
 
@@ -21,6 +20,11 @@ from Orange.widgets.widget import OWWidget, Msg, Input, Output
 from Orange.preprocess.preprocess import Normalize
 from scipy.interpolate import splprep, splev
 
+try:
+    from orangewidget.report import report
+except ImportError:
+    from Orange.canvas import report
+
 from orangecontrib.educational.widgets.utils.color_transform import (
     rgb_to_hex, hex_to_rgb)
 from orangecontrib.educational.widgets.utils.linear_regression import \
@@ -160,6 +164,7 @@ class OWGradientDescent(OWWidget):
                   "on logistic regression."
     icon = "icons/GradientDescent.svg"
     want_main_area = True
+    priority = 400
 
     class Inputs:
         data = Input("Data", Table)
@@ -827,7 +832,7 @@ class OWGradientDescent(OWWidget):
         """
         if self.learner is not None and self.learner.theta is not None:
             domain = Domain(
-                    [ContinuousVariable("Coefficients", number_of_decimals=7)],
+                    [ContinuousVariable("Coefficients")],
                     metas=[StringVariable("Name")])
             names = ["theta 0", "theta 1"]
 
