@@ -19,7 +19,11 @@ from Orange.widgets.utils.owlearnerwidget import OWBaseLearner
 from Orange.classification import (LogisticRegressionLearner, Learner,
                                    RandomForestLearner, TreeLearner)
 from Orange.widgets.widget import Msg, OWWidget, Input, Output
-from Orange.canvas import report
+
+try:
+    from orangewidget.report import report
+except ImportError:
+    from Orange.canvas import report
 
 from orangecontrib.educational.widgets.utils.polynomialtransform \
     import PolynomialTransform
@@ -73,6 +77,7 @@ class OWPolynomialClassification(OWBaseLearner):
     icon = "icons/polynomialclassification.svg"
     want_main_area = True
     resizing_enabled = True
+    priority = 600
 
     # inputs and outputs
     class Inputs(OWBaseLearner.Inputs):
@@ -331,7 +336,7 @@ class OWPolynomialClassification(OWBaseLearner):
             dict(
                 data=[list(p.attributes())
                       for p in sd
-                      if (int(p.metas[0]) == _class and
+                      if (p.metas[0] == _class and
                           all(v is not None for v in p.attributes()))],
                 type="scatter",
                 zIndex=10,
@@ -341,6 +346,17 @@ class OWPolynomialClassification(OWBaseLearner):
                 name=sd.domain.metas[0].values[_class])
             for _class in range(len(sd.domain.metas[0].values))]
 
+        # add nan values as a gray dots
+        options['series'] += [
+            dict(
+                data=[list(p.attributes())
+                      for p in sd
+                      if np.isnan(p.metas[0])],
+                type="scatter",
+                zIndex=10,
+                color=rgb_to_hex((160, 160, 160)),
+                showInLegend=False)]
+
         cls_domain = sd.domain.metas[0]
 
         target_idx = cls_domain.values.index(self.target_class)
@@ -607,8 +623,7 @@ class OWPolynomialClassification(OWBaseLearner):
                 hasattr(self.model, 'skl_model')):
             model = self.model.skl_model
             domain = Domain(
-                [ContinuousVariable("coef", number_of_decimals=7)],
-                metas=[StringVariable("name")])
+                [ContinuousVariable("coef")], metas=[StringVariable("name")])
             coefficients = (model.intercept_.tolist() +
                             model.coef_[0].tolist())
 
